### Installation

> pip install gl-1106

### Get started
How to use this package:

```
from get_data import *
to using the Polygon_data.py which is including the main function and unit function

# change to your currency pairs for test Max code
currency_pairs = [["AUD","USD",[],portfolio("AUD","USD")],
                  ["GBP","EUR",[],portfolio("GBP","EUR")],
                   ["USD","CAD",[],portfolio("USD","CAD")]]

main(currency_pairs)
```